@@ -1,4 +1,4 @@
-import qiniu.conf
+ import qiniu.conf
 import qiniu.rs
 import qiniu.rsf
 import qiniu.io
@@ -19,11 +19,11 @@ class Storage(driver.Base):
 
         self._bucket = config.qiniu_bucket
         self._domain = config.qiniu_domain
-        
+
         self._putpolicy = qiniu.rs.PutPolicy(config.qiniu_bucket)
         self._getpolicy = qiniu.rs.GetPolicy()
         self._uptoken = self._putpolicy.token()
-        
+
     def _init_path(self, path=None):
         if path:
             if path.startswith('/'):
@@ -53,9 +53,10 @@ class Storage(driver.Base):
         try:
             base_url = qiniu.rs.make_base_url(self._domain, path)
             get_url = self._getpolicy.make_request(base_url)
-            response = urllib.Request.urlopen(get_url)
-        except:
-            raise exceptions.FileNotFoundError('%s is not there' % path)
+            print get_url
+            response = urllib.urlopen(get_url)
+        except Exception as e:
+            raise exceptions.FileNotFoundError('%s is not there %s, e: %s' % (path, get_url, e))
 
         try:
             while True:
@@ -124,22 +125,23 @@ class Storage(driver.Base):
             marker = None
             err = None
             counter = 0
-            
+
             while err is None:
-                ret, err = rs.list_prefix(bucket_name, prefix=path, marker=marker)
+                ret, err = rs.list_prefix(self._bucket, prefix=path, marker=marker)
                 marker = ret.get('marker', None)
                 for item in ret['items']:
                     counter += 1
-                    yield item[0]
-            
+                    yield item['key']
+
             if err is not qiniu.rsf.EOF:
                 print err
                 raise IOError("List path %s err: %s" % (path, err))
-            
+
             if counter == 0:
+                print 'empty'
                 Exception("empty")
-        except Exception:
-            raise exceptions.FileNotFoundError('%s is not there' % path)
+        except Exception as e:
+            raise exceptions.FileNotFoundError('%s is not there err: %s' % (path, e))
 
     def exists(self, path):
         path = self._init_path(path)
@@ -154,14 +156,20 @@ class Storage(driver.Base):
         path = self._init_path(path)
 
         try:
-            self.head_store(path)
-        except Exception:
-            raise exceptions.FileNotFoundError('%s is not there' % path)
-
-        ret, err = qiniu.rs.Client().delete(self._bucket, path)
-        if err is not None:
-            print err
-            raise IOError("List path %s err: %s" % (path, err))
+            items = list(self.list_directory(path))
+            if len(items) > 0:
+                paths = []
+                for item in items:
+                    paths.append(qiniu.rs.EntryPath(self._bucket, item))
+                rets, err = qiniu.rs.Client().batch_delete(paths)
+                if err is not None:
+                    print err
+                    raise IOError("Remove path %s err: %s" % (path, err))
+            else:
+                print 'empty'
+                Exception("empty")
+        except Exception as e:
+            raise exceptions.FileNotFoundError('Remove %s is err: %s' % (path, e))
 
     def get_size(self, path):
         path = self._init_path(path)
@@ -169,4 +177,4 @@ class Storage(driver.Base):
             headers = self.head_store(path)
             return headers['fsize']
         except Exception:
-            raise exceptions.FileNotFoundError('%s is not there' % path)
+            raise exceptions.FileNotFoundError('%s is not there' % path)
\ No newline at end of file
